@@ -97,8 +97,11 @@ def process_path(root, idx, path):
     # as children of the main root.
     doc = etree.parse(path)
     node = doc.getroot()
+    new_path = split_base_path(path)
     children1 = reversed(node.getchildren())
     for child1 in children1:
+        if child1.__class__ is etree._Element:
+            child1.set('path_', new_path)
         root.insert(idx, copy.copy(child1))
 
 def process_include_statements(root):
@@ -123,13 +126,15 @@ def process_include_statements(root):
                 continue
             repl = etree.Comment(etree.tostring(child))
             root.replace(child, repl)
-            if os.path.exists(path):
-                process_path(root, idx, path)
+            path1 = make_path(root, path)
+            if os.path.exists(path1):
+                process_path(root, idx, path1)
             else:
                 for d in DIRPATH:
-                    path = os.path.join(d,locn)
-                    if os.path.exists(path):
-                        process_path(root, idx, path)
+                    path = make_path(root, path)
+                    path1 = os.path.join(d,locn)
+                    if os.path.exists(path1):
+                        process_path(root, idx, path1)
                         break
                 else:
                     msg = "Can't find include file %s.  Aborting." % (path, )
@@ -151,13 +156,15 @@ def process_include_statements(root):
                     msg = "Can't retrieve import file %s.  Aborting." % (locn, )
                     raise IOError(msg)
             else:
-                if os.path.exists(locn):
-                    process_path(root, idx, locn)
+                path1 = make_path(child, locn)
+                if os.path.exists(path1):
+                    process_path(root, idx, path1)
                 else:
                     for d in DIRPATH:
-                        path = os.path.join(d,locn)
-                        if os.path.exists(path):
-                            process_path(root, idx, path)
+                        path = make_path(root, locn)
+                        path1 = os.path.join(d,locn)
+                        if os.path.exists(path1):
+                            process_path(root, idx, path1)
                             break
                     else:
                         msg = "Can't find import file %s.  Aborting." % (locn, )
@@ -179,6 +186,17 @@ def make_file(outFileName):
     return outFile
 
 
+def split_base_path(path):
+    path1 = os.path.split(path)[0]
+    return path1
+
+
+def make_path(root, path):
+    path1 = root.get('path_', '.')
+    path2 = '%s/%s' % (path1, path, )
+    return path2
+
+
 USAGE_TEXT = __doc__
 
 def usage():
